==> prestashop_1.3.7.0.zip: prestashop/modules/productcomments/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{productcomments}prestashop>productcomments_b91c4e8b229a399a3bc911d352524a9b'] = 'Comentario sobre el producto';
$_MODULE['<{productcomments}prestashop>productcomments_eb4783ce47d29a12b944635fc255893f'] = 'Permitir a los usuarios registrar comentarios acerca del producto';
$_MODULE['<{productcomments}prestashop>productcomments_f4d1ea475eaa85102e2b4e6d95da84bd'] = 'Confirmación';
$_MODULE['<{productcomments}prestashop>productcomments_c888438d14855d7d96a2724ee9c306bd'] = 'Ajustes actualizados';
$_MODULE['<{productcomments}prestashop>productcomments_0a36c5f3ea6825804e6b4314c4084a12'] = 'Moderar Comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_519532ca486f468a9dd44232e7b0cafa'] = 'Se necesita validación';
$_MODULE['<{productcomments}prestashop>productcomments_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Autorizado';
$_MODULE['<{productcomments}prestashop>productcomments_b9f5c797ebbf55adccdd8539a65a0241'] = 'No autorizado';
$_MODULE['<{productcomments}prestashop>productcomments_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{productcomments}prestashop>productcomments_06df33001c1d7187fdd81ea1f5b277aa'] = 'Acciones';
$_MODULE['<{productcomments}prestashop>productcomments_a517747c3d12f99244ae598910d979c5'] = 'Autor';
$_MODULE['<{productcomments}prestashop>productcomments_0be8406951cdfda82f00f79328cf4efc'] = 'Comentario';
$_MODULE['<{productcomments}prestashop>productcomments_df644ae155e79abf54175bd15d75f363'] = 'Nombre del producto';
$_MODULE['<{productcomments}prestashop>productcomments_c4408d335012a56ff58937d78050efad'] = 'Aceptar';
$_MODULE['<{productcomments}prestashop>productcomments_f2a6c498fb90ee345d997f888fce3b18'] = 'Eliminar';
$_MODULE['<{productcomments}prestashop>productcomments_0e1a03b7b26ffce9312556aa4de91a00'] = 'No hay comentarios para validar.';
$_MODULE['<{productcomments}prestashop>productcomments_0048bfb5ec7540fce6a8262321abb68b'] = 'Criterios de los comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_5425e30a4f2d17eebb3ccbc8d9e4b879'] = 'Criterio de los comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_ec211f7c20af43e742bf2570c3cb84f9'] = 'Añadir';
$_MODULE['<{productcomments}prestashop>productcomments_549f9fb7be6d7edda6c5560f4ec30be4'] = 'Cree un nuevo criterio de clasificación para sus productos.';
$_MODULE['<{productcomments}prestashop>productcomments_dd33a09f24a2e9e889b7f1f1a0255c22'] = 'Una vez creado, debe activarlo para los productos deseados bajo la siguiente forma.';
$_MODULE['<{productcomments}prestashop>productcomments_daa1f0640f2e6759e4b4f2b981b21285'] = 'Tenga presente que los criterios son independientes en cada idioma.';
$_MODULE['<{productcomments}prestashop>productcomments_21a512e9d635e82fc7c7077fc880988b'] = 'Criterio';
$_MODULE['<{productcomments}prestashop>productcomments_e04d057b0b4f26f6d67294bb953fa84b'] = 'Criterios de los productos';
$_MODULE['<{productcomments}prestashop>productcomments_5d4b6d89c4c760deacf872899482ff06'] = 'Seleccione los criterios de clasificación que corresponden a cada producto. Puede seleccionar criterios múltiples pulsando la tecla Ctrl.';
$_MODULE['<{productcomments}prestashop>productcomments_deb10517653c255364175796ace3553f'] = 'Producto';
$_MODULE['<{productcomments}prestashop>productcomments_92c8811185c56998dfbcbdd30ad649d3'] = 'Criterios de clasificación';
$_MODULE['<{productcomments}prestashop>productcomments_7b2f2ea0f690ef3c2fc9bba0e4bfbc4c'] = 'Comentario texto no válido para una publicación.';
$_MODULE['<{productcomments}prestashop>productcomments_06316a7f66070d83b0be475d1548d5ad'] = 'Se ha producido un error al guardar su comentario.';
$_MODULE['<{productcomments}prestashop>productcomments_ad4ec284804b5d44a3e6de6c851e2731'] = 'Comentario publicado con éxito.';
$_MODULE['<{productcomments}prestashop>productcomments_e1549cfa9780c9c706f9ea8fdc25e441'] = 'En espera de validación del moderador.';
$_MODULE['<{productcomments}prestashop>productcomments_6bf852d9850445291f5e9d4740ac7b50'] = 'Se necesita el texto del comentario.';
$_MODULE['<{productcomments}prestashop>productcomments_6d28f2900adb9e500868166f6d04da92'] = 'Espere por favor';
$_MODULE['<{productcomments}prestashop>productcomments_441f4c06170a0c047e62e4d8a3ea67d5'] = 'hora(s) antes de enviar un nuevo comentario';
$_MODULE['<{productcomments}prestashop>productcomments_7c3b0e9898b88deee7ea75aafd2e37e2'] = 'Grado medio';
$_MODULE['<{productcomments}prestashop>productcomments_b1897515d548a960afe49ecf66a29021'] = 'Promedio';
$_MODULE['<{productcomments}prestashop>productcomments_5da618e8e4b89c66fe86e32cdafde142'] = 'Desde';
$_MODULE['<{productcomments}prestashop>productcomments_08621d00a3a801b9159a11b8bbd69f89'] = 'No hay comentarios de clientes por ahora.';
$_MODULE['<{productcomments}prestashop>productcomments_c3edcf2cedbd4ce230fd6d4ea8915718'] = 'Añadir un comentario';
$_MODULE['<{productcomments}prestashop>productcomments_94966d90747b97d1f0f206c98a8b1ac3'] = 'Enviar';
$_MODULE['<{productcomments}prestashop>productcomments_720fae7db6e6055d2b47890240bb3598'] = 'Solamente los usuarios registrados pueden introducir comentarios.';
$_MODULE['<{productcomments}prestashop>tab_8413c683b4b27cc3f4dbd4c90329d8ba'] = 'Comentarios';

==> prestashop_1.4.0.2.zip: prestashop/modules/productcomments/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{productcomments}prestashop>productcomments_b91c4e8b229a399a3bc911d352524a9b'] = 'Comentario sobre el producto';
$_MODULE['<{productcomments}prestashop>productcomments_eb4783ce47d29a12b944635fc255893f'] = 'Permitir a los usuarios registrar comentarios acerca del producto';
$_MODULE['<{productcomments}prestashop>productcomments_f4d1ea475eaa85102e2b4e6d95da84bd'] = 'Confirmación';
$_MODULE['<{productcomments}prestashop>productcomments_c888438d14855d7d96a2724ee9c306bd'] = 'Ajustes actualizados';
$_MODULE['<{productcomments}prestashop>productcomments_1bb54e382f7dbdb260f0aa6b42bb624b'] = 'Criterio suprimido';
$_MODULE['<{productcomments}prestashop>productcomments_21b0922096daf5c742cc98986d857cc1'] = 'Criterio actualizado';
$_MODULE['<{productcomments}prestashop>productcomments_254f642527b45bc260048e30704edb39'] = 'Configuración';
$_MODULE['<{productcomments}prestashop>productcomments_519532ca486f468a9dd44232e7b0cafa'] = 'Se necesita validación';
$_MODULE['<{productcomments}prestashop>productcomments_00d23a76e43b46dae9ec7aa9dcbebb32'] = 'Autorizado';
$_MODULE['<{productcomments}prestashop>productcomments_b9f5c797ebbf55adccdd8539a65a0241'] = 'No autorizado';
$_MODULE['<{productcomments}prestashop>productcomments_18d52ddfed043367596350023ea0f1e8'] = 'Plazo mínimo entre dos comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_c9cc8cce247e49bae79f15173ce97354'] = 'Guardar';
$_MODULE['<{productcomments}prestashop>productcomments_0a36c5f3ea6825804e6b4314c4084a12'] = 'Moderar Comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_a517747c3d12f99244ae598910d979c5'] = 'Autor';
$_MODULE['<{productcomments}prestashop>productcomments_0be8406951cdfda82f00f79328cf4efc'] = 'Comentario';
$_MODULE['<{productcomments}prestashop>productcomments_df644ae155e79abf54175bd15d75f363'] = 'Nombre del producto';
$_MODULE['<{productcomments}prestashop>productcomments_06df33001c1d7187fdd81ea1f5b277aa'] = 'Acciones';
$_MODULE['<{productcomments}prestashop>productcomments_c4408d335012a56ff58937d78050efad'] = 'Aceptar';
$_MODULE['<{productcomments}prestashop>productcomments_f2a6c498fb90ee345d997f888fce3b18'] = 'Eliminar';
$_MODULE['<{productcomments}prestashop>productcomments_8bf0c707232d63bf83b4b2467d2df41a'] = 'Selección:';
$_MODULE['<{productcomments}prestashop>productcomments_0e1a03b7b26ffce9312556aa4de91a00'] = 'No hay comentarios para validar.';
$_MODULE['<{productcomments}prestashop>productcomments_0048bfb5ec7540fce6a8262321abb68b'] = 'Criterios de los comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_5425e30a4f2d17eebb3ccbc8d9e4b879'] = 'Criterio de los comentarios';
$_MODULE['<{productcomments}prestashop>productcomments_d3f2a59c82bae60060aef6e938a08893'] = 'Aplicar a ';
$_MODULE['<{productcomments}prestashop>productcomments_4d3d769b812b6faa6b76e1a8abaece2d'] = 'Activo';
$_MODULE['<{productcomments}prestashop>productcomments_549f9fb7be6d7edda6c5560f4ec30be4'] = 'Cree un nuevo criterio de clasificación para sus productos.';
$_MODULE['<{productcomments}prestashop>productcomments_dd33a09f24a2e9e889b7f1f1a0255c22'] = 'Una vez creado, debe activarlo para los productos deseados bajo la siguiente forma.';
$_MODULE['<{productcomments}prestashop>productcomments_21a512e9d635e82fc7c7077fc880988b'] = 'Criterio';
$_MODULE['<{productcomments}prestashop>productcomments_a1fa27779242b4902f7ae3bdd5c6d508'] = 'Tipo ';
$_MODULE['<{productcomments}prestashop>productcomments_ec53a8c4f07baed5d8825072c89799be'] = 'Estado';
$_MODULE['<{productcomments}prestashop>productcomments_7dce122004969d56ae2e0245cb754d35'] = 'Modificar';
$_MODULE['<{productcomments}prestashop>productcomments_463f56f3147de6617801e57bebd3f53e'] = 'Aplicación criterios';
$_MODULE['<{productcomments}prestashop>productcomments_92c8811185c56998dfbcbdd30ad649d3'] = 'Criterios de clasificación';
$_MODULE['<{productcomments}prestashop>productcomments_068f80c7519d0528fb08e82137a72131'] = 'Productos';
$_MODULE['<{productcomments}prestashop>productcomments_af1b98adf7f686b84cd0b443e022b7a0'] = 'Categorías';
$_MODULE['<{productcomments}prestashop>productcomments_b718adec73e04ce3ec720dd11a06a308'] = 'ID';
$_MODULE['<{productcomments}prestashop>productcomments_b9aefa40a54680bb258f9f9569290fae'] = 'Nombre del producto';
$_MODULE['<{productcomments}prestashop>productcomments_99121ab27aaa7472cfada9071c5ba434'] = 'Nombre de la categoría';
$_MODULE['<{productcomments}prestashop>productcomments_fd4b5401d4d3c7d32d158bfc1e552f3b'] = 'Por favor, escriba su nombre';
$_MODULE['<{productcomments}prestashop>productcomments_7b2f2ea0f690ef3c2fc9bba0e4bfbc4c'] = 'Comentario texto no válido para una publicación.';
$_MODULE['<{productcomments}prestashop>productcomments_06316a7f66070d83b0be475d1548d5ad'] = 'Se ha producido un error al guardar su comentario.';
$_MODULE['<{productcomments}prestashop>productcomments_ad4ec284804b5d44a3e6de6c851e2731'] = 'Comentario publicado con éxito.';
$_MODULE['<{productcomments}prestashop>productcomments_e1549cfa9780c9c706f9ea8fdc25e441'] = 'En espera de validación del moderador.';
$_MODULE['<{productcomments}prestashop>productcomments_6bf852d9850445291f5e9d4740ac7b50'] = 'Se necesita el texto del comentario.';
$_MODULE['<{productcomments}prestashop>productcomments_6d28f2900adb9e500868166f6d04da92'] = 'Espere por favor';
$_MODULE['<{productcomments}prestashop>productcomments_5a044284419260a7d7cc6c4e34f2f4b4'] = 'minuto(s) antes de enviar un nuevo comentario';
$_MODULE['<{productcomments}prestashop>productcomments_7c3b0e9898b88deee7ea75aafd2e37e2'] = 'Grado medio';
$_MODULE['<{productcomments}prestashop>productcomments_b1897515d548a960afe49ecf66a29021'] = 'Promedio';
$_MODULE['<{productcomments}prestashop>productcomments_5da618e8e4b89c66fe86e32cdafde142'] = 'Desde';
$_MODULE['<{productcomments}prestashop>productcomments_08621d00a3a801b9159a11b8bbd69f89'] = 'No hay comentarios de clientes por ahora.';
$_MODULE['<{productcomments}prestashop>productcomments_441f4c06170a0c047e62e4d8a3ea67d5'] = 'hora(s) antes de enviar un nuevo comentario';
$_MODULE['<{productcomments}prestashop>productcomments_c3edcf2cedbd4ce230fd6d4ea8915718'] = 'Añadir un comentario';
$_MODULE['<{productcomments}prestashop>productcomments_221e705c06e231636fdbccfdd14f4d5c'] = 'Su nombre';
$_MODULE['<{productcomments}prestashop>productcomments_94966d90747b97d1f0f206c98a8b1ac3'] = 'Enviar';
$_MODULE['<{productcomments}prestashop>productcomments_720fae7db6e6055d2b47890240bb3598'] = 'Solamente los usuarios registrados pueden introducir comentarios.';
$_MODULE['<{productcomments}prestashop>products-comparison_8413c683b4b27cc3f4dbd4c90329d8ba'] = 'Comentarios';
$_MODULE['<{productcomments}prestashop>products-comparison_b1897515d548a960afe49ecf66a29021'] = 'Media';
$_MODULE['<{productcomments}prestashop>products-comparison_bc976f6c3405523cde61f63a7cbe224b'] = 'Ver las opiniones';
$_MODULE['<{productcomments}prestashop>tab_8413c683b4b27cc3f4dbd4c90329d8ba'] = 'Comentarios';
